Installation
============

``FinOL`` is available on `PyPI <https://pypi.org/project/finol>`__,
we recommend to install ``FinOL`` via pip:

.. code-block:: bash

   $ pip install --upgrade finol

You can also install the development version of ``FinOL``
from master branch of Git repository:

.. code-block:: bash

    $ pip install git+https://github.com/jiahaoli57/finol.git